# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- n/a

## [1.1.0] - 2019-08-01

### Changed

- Push item "filename" is no longer restricted to basenames only.

## [1.0.0] - 2019-07-24

### Changed
- Version set to 1.0.0 to indicate that API is now considered stable

## 0.1.1 - 2019-07-11

- Initial release to PyPI

[Unreleased]: https://github.com/release-engineering/pushcollector/compare/v1.1.0...HEAD
[1.1.0]: https://github.com/release-engineering/pushcollector/compare/v1.0.0...v1.1.0
[1.0.0]: https://github.com/release-engineering/pushcollector/compare/v0.1.1...v1.0.0
